@@ -36,7 +36,10 @@ trait ProphecyTrait
      * @throws DoubleException
      * @throws InterfaceNotFoundException
      *
-     * @psalm-param class-string|null $classOrInterface
+     * @template T of object
+     * @phpstan-param class-string<T>|null $classOrInterface
+     * @phpstan-return ($classOrInterface is null ? ObjectProphecy<object> : ObjectProphecy<T>)
+     *
      * @not-deprecated
      */
     protected function prophesize(?string $classOrInterface = null): ObjectProphecy
@@ -95,6 +98,7 @@ trait ProphecyTrait
     private function countProphecyAssertions(): void
     {
         \assert($this instanceof TestCase);
+        \assert($this->prophet !== null);
         $this->prophecyAssertionsCounted = true;
 
         foreach ($this->prophet->getProphecies() as $objectProphecy) {
